@@ -107,9 +107,7 @@ def comment_deployment_changes_on_pr(repository, pull_request_number):
         url = file_info["raw_url"]
         old_file, new_file = get_files(get_master_url(url), url, headers)
         new_versions_block = get_versions_dict(new_file)
-        new_is_nde_portal = "data-ecosystem-portal" in new_versions_block.get(
-            "portal", ""
-        )
+        new_portal_type = get_image_name(new_versions_block.get("portal", ""))
 
         for service_name in IGNORED_SERVICES:
             new_versions_block.pop(service_name, None)
@@ -119,17 +117,15 @@ def comment_deployment_changes_on_pr(repository, pull_request_number):
             for service_name in IGNORED_SERVICES:
                 old_versions_block.pop(service_name, None)
 
-            old_is_nde_portal = "data-ecosystem-portal" in old_versions_block.get(
-                "portal", ""
-            )
+            old_portal_type = get_image_name(new_versions_block.get("portal", ""))
             # we only compare portal versions from the same repo
             compared_versions = compare_versions_blocks(
                 old_versions_block,
                 new_versions_block,
-                old_is_nde_portal == new_is_nde_portal,
+                new_portal_type == old_portal_type,
             )
-            deployment_changes, breaking_changes = get_important_changes(
-                compared_versions, token, new_is_nde_portal
+            deployment_changes, breaking_changes, comment_notes = get_important_changes(
+                compared_versions, token, new_portal_type
             )
             downgraded_services = get_downgraded_services(compared_versions)
         else:
@@ -137,16 +133,18 @@ def comment_deployment_changes_on_pr(repository, pull_request_number):
             deployment_changes = {}
             breaking_changes = {}
             downgraded_services = {}
+            comment_notes = ""
         contents = generate_comment(
             deployment_changes,
             breaking_changes,
             check_services_on_branch(new_versions_block),
             downgraded_services,
+            comment_notes,
         )
         if contents:
             full_comment += "# {}\n{}".format(file_info["filename"], contents)
     if full_comment:
-        logger.info(full_comment)
+        logger.info(f"Comment:\n{full_comment}")
         submit_comment(full_comment, headers, pr_comments_url)
 
 
@@ -204,7 +202,13 @@ def get_versions_dict(manifest):
         manifest.get("ssjdispatcher", {}).get("job_images", {}).items()
     ):
         versions[f"ssjdispatcher.job_images.{ssj_name}"] = ssj_image
-    for sower_job in manifest.get("sower", []):
+    sower_job_object = manifest.get("sower", [])
+
+    # Older manifests have sower_job_data as a dictionary
+    if type(sower_job_object) is dict:
+        sower_job_object = [sower_job_object]
+
+    for sower_job in sower_job_object:
         container = sower_job.get("container", {})
         image = container.get("image")
         if image:
@@ -267,7 +271,7 @@ def compare_versions_blocks(old_versions_block, new_versions_block, check_portal
     return res
 
 
-def get_important_changes(versions_dict, token, is_nde_portal):
+def get_important_changes(versions_dict, token, portal_type):
     """
     Uses the gen3git utility to get the release notes between the old and new
     versions for each service, and returns the deployment changes and breaking
@@ -297,36 +301,63 @@ def get_important_changes(versions_dict, token, is_nde_portal):
 
     deployment_changes = {}
     breaking_changes = {}
+    comment_notes = ""
+    release_notes_cache = {}
     for service, versions in versions_dict.items():
         # only get the deployment changes if the new version is more
         # recent than the old version. ignore services on a branch
         if not version_is_branch(
             versions["old"], release_tag_are_branches=False
         ) and not version_is_branch(versions["new"], release_tag_are_branches=False):
-            repo_name = get_repo_name(service, is_nde_portal)
+            repo_name = get_repo_name(service, portal_type)
             logger.debug(f"Mapped service/image name '{service}' to repo '{repo_name}'")
-            args = Gen3GitArgs(repo_name, versions["old"], versions["new"])
-            try:
-                release_notes = gen3git.main(args)
-                if not release_notes:
-                    raise Exception("gen3git did not return release notes")
-            except Exception:
-                logger.error(
-                    "While checking service '{}', repo '{}', unable to get release notes with gen3git:".format(
-                        service, repo_name
+            cache_key = f"{repo_name}_{versions['old']}_{versions['new']}"
+            release_notes = release_notes_cache.get(cache_key)
+            if not release_notes:
+                args = Gen3GitArgs(repo_name, versions["old"], versions["new"])
+                try:
+                    release_notes = gen3git.main(args)
+                    if not release_notes:
+                        raise Exception("gen3git did not return release notes")
+                except requests.exceptions.HTTPError as e:
+                    logger.error(
+                        "While checking service '{}', repo '{}', unable to get release notes with gen3git. Got HTTP error: {}".format(
+                            service, repo_name, e
+                        )
                     )
-                )
-                raise
+                    if e.response.status_code == 429:
+                        comment_notes = ":warning: This check was rate limited! Only returning release notes obtained before reaching the limit. Try setting a GITHUB_TOKEN or lowering the amount of changes in your PR (fewer version changes, or less time difference between versions)."
+                        break
+                    raise
+                except Exception:
+                    logger.error(
+                        "While checking service '{}', repo '{}', unable to get release notes with gen3git:".format(
+                            service, repo_name
+                        )
+                    )
+                    raise
+                release_notes_cache[cache_key] = release_notes
             notes = release_notes.get("deployment changes")
             if notes:
                 deployment_changes[service] = update_pr_links(repo_name, notes)
             notes = release_notes.get("breaking changes")
             if notes:
                 breaking_changes[service] = update_pr_links(repo_name, notes)
-    return deployment_changes, breaking_changes
+
+    return deployment_changes, breaking_changes, comment_notes
 
 
-def get_repo_name(service, is_nde_portal=False):
+def get_image_name(version):
+    """
+    input: "707767160287.dkr.ecr.us-east-1.amazonaws.com/gen3/dataguids:1.0.2"
+    output: "dataguids"
+    """
+    image_name = version.split(":")[0]
+    image_name = image_name.split("/")[-1]
+    return image_name
+
+
+def get_repo_name(service, portal_type="data-portal"):
     # by default, assume the code lives in repo uc-cdis/<service name>
     repo_name = SERVICE_TO_REPO.get(service, service)
 
@@ -338,8 +369,11 @@ def get_repo_name(service, is_nde_portal=False):
                 break
 
     # repo names special cases
-    if service == "portal" and is_nde_portal:
-        repo_name = "data-ecosystem-portal"
+    if service == "portal":
+        if portal_type == "data-ecosystem-portal":
+            repo_name = "data-ecosystem-portal"
+        elif portal_type == "dataguids":
+            repo_name = "dataguids.org"
 
     return "uc-cdis/" + repo_name
 
@@ -350,6 +384,11 @@ def get_downgraded_services(compared_versions):
     """
     downgraded_services = set()
     for service, versions in compared_versions.items():
+        if version_is_branch(
+            versions["old"], release_tag_are_branches=False
+        ) or version_is_branch(versions["new"], release_tag_are_branches=False):
+            # we can't compare branches
+            continue
         old_is_monthly = version_is_monthly_release(versions["old"])
         new_is_monthly = version_is_monthly_release(versions["new"])
         if old_is_monthly != new_is_monthly:
@@ -367,7 +406,10 @@ def check_services_on_branch(versions_block):
     services_on_branch = []
     for service in versions_block:
         version = versions_block.get(service)
-        if "quay.io/cdis" not in version or len(version.split(":")) < 2:
+        if (
+            "quay.io/cdis" not in version
+            and "dkr.ecr.us-east-1.amazonaws.com" not in version
+        ) or len(version.split(":")) < 2:
             # ignore non-CTDS repos.
             # version without ":" is not usable.
             continue
@@ -397,12 +439,18 @@ def update_pr_links(repo_name, notes_list):
 
 
 def generate_comment(
-    deployment_changes, breaking_changes, services_on_branch, downgraded_services
+    deployment_changes,
+    breaking_changes,
+    services_on_branch,
+    downgraded_services,
+    comment_notes,
 ):
     # TODO: edit the previous comment instead of posting a new one
     contents = ""
+    if comment_notes:
+        contents += "## {}\n".format(comment_notes)
     if services_on_branch:
-        contents += "## :warning: Services on branch\n- {}\n".format(
+        contents += "## :warning: Services on a branch\n- {}\n".format(
             "\n- ".join(services_on_branch)
         )
     if downgraded_services:
