@@ -6,6 +6,6 @@ def init_dictionary(url):
     dictionary.init(d)
     # the gdcdatamodel expects dictionary initiated on load, so this can't be
     # imported on module level
-    from gdcdatamodel import models as md
+    from gen3datamodel import models as md
 
     return d, md
