@@ -167,7 +167,6 @@ def validate_joining_src(json_obj, recorded_errors, joining_props):
         if src not in joining_props:
             if alternate_src in joining_props:
                 print("WARN: Utilizing alternate src")
-                return
             recorded_errors.append(
                 FieldError(
                     'src field "{}" (declared in "{}") is not found in joining index.'.format(
@@ -450,14 +449,12 @@ def validate_mapping(dictionary_url, mapping_file, manifest):
     tube_version = get_manifest_version(
         manifest["versions"], "tube", release_tag_are_branches=False, warn=False
     )
-    underscore = False
+    underscore = True
     if tube_version is not None and type(tube_version) != str:  # str if branch
-        if not is_release_tag(tube_version) and tube_version >= version.parse("0.4.0"):
-            underscore = True
-        elif tube_version >= version.parse("2020.10"):
-            underscore = True
-    if tube_version == "master":
-        underscore = True
+        if tube_version < version.parse("0.4.0") or (
+            is_release_tag(tube_version) and tube_version < version.parse("2020.10")
+        ):
+            underscore = False
 
     recorded_errors = check_mapping_format(mappings, [])
     if len(recorded_errors) > 0:
